@@ -38,6 +38,8 @@ import time
 import uuid
 import xlrd
 
+import dask.dataframe as dd
+
 
 class MultiTaskPool:
     def __init__(self):
@@ -255,6 +257,8 @@ def resize_and_retrieve(url, filename):
     try:
         response = requests.get(url)
         img = Image.open(BytesIO(response.content))
+        if img.mode in ("RGBA", "P"):
+            img = img.convert("RGB")
         img = img.resize((TARGET_RESOLUTION, TARGET_RESOLUTION))
         img.save(filename)
     except Exception as e:
@@ -349,11 +353,12 @@ def download_commit_db_images(url_images, url_produits):
     else:
         for product in url_produits.keys():
             try:
-                download_or_remove(url_produits.get(product, {}).get('images', ''), product,
-                                   url_produits.get(product, {}).get("customer_name"),
-                                   url_produits.get(product, {}).get('customer_type'), db,
-                                   url_produits.get(product, {}).get('path'),
-                                   url_produits.get(product, {}).get('project_name'))
+                for img in url_produits[product]['images']:
+                    download_or_remove(img, product,
+                                       url_produits.get(product, {}).get("customer_name"),
+                                       url_produits.get(product, {}).get('customer_type'), db,
+                                       url_produits.get(product, {}).get('path'),
+                                       url_produits.get(product, {}).get('project_name'))
             except Exception as e:
                 logger.error('Error_url_produits_download_commit_db_images_cont %s downloading image %s continue' %
                              (e, url_produits[product]['images']))
@@ -907,6 +912,8 @@ def fine_tune(IMG_HEIGHT, IMG_WIDTH, NUM_CLASSES):
                            metrics=['accuracy'])
     return parallel_model, model
 
+
+
 def load_vectors_from_local(vectors, users):
     '''
     :param vectors: dict with vectors names and values initialised to empty dict
@@ -927,8 +934,9 @@ def load_vectors_from_local(vectors, users):
                                 if vector_name not in vectors.keys():
                                     logger.info(
                                         'Vector to load  =====> %s' % (vector))
-                                    vector_data = pd.read_parquet(path=vector_path + project + '/' + vector,
+                                    vector_data = dd.read_parquet(vector_path + project + '/' + vector,
                                                                   engine='pyarrow')
+
                                     vectors[vector_name] = vector_data
                                     if vector_data is not None:
                                         vectors[vector_name] = vector_data
